==> Slicer3-3.0.2007-12-17-linux-x86.tar.gz: Slicer3-3.0.2007-12-17-linux-x86/lib/vtk-5.0/VTKLibraryDepends.cmake <==
SET(vtkCommon_LIB_DEPENDS "vtksys;-lpthread;dl;-lm;")
SET(vtkCommonTCL_LIB_DEPENDS "vtkCommon;/home/hayes/dart-slicer3-nightly/Slicer3/../Slicer3-lib/tcl-build/lib/libtcl8.4.so;m;")
SET(vtkFiltering_LIB_DEPENDS "vtkCommon;")
SET(vtkFilteringTCL_LIB_DEPENDS "vtkFiltering;vtkCommonTCL;")
SET(vtkImaging_LIB_DEPENDS "vtkFiltering;")
SET(vtkImagingTCL_LIB_DEPENDS "vtkImaging;vtkFilteringTCL;")
SET(vtkGraphics_LIB_DEPENDS "vtkFiltering;")
SET(vtkGraphicsTCL_LIB_DEPENDS "vtkGraphics;vtkFilteringTCL;")
SET(vtkGenericFiltering_LIB_DEPENDS "vtkFiltering;vtkGraphics;")
SET(vtkGenericFilteringTCL_LIB_DEPENDS "vtkGenericFiltering;vtkFilteringTCL;vtkGraphicsTCL;")
SET(vtkIO_LIB_DEPENDS "vtkFiltering;vtkDICOMParser;vtkpng;vtkzlib;vtkjpeg;vtktiff;vtkexpat;")
SET(vtkIOTCL_LIB_DEPENDS "vtkIO;vtkFilteringTCL;")
SET(vtkRendering_LIB_DEPENDS "vtkGraphics;vtkImaging;vtkIO;vtkftgl;vtkfreetype;/usr/lib/libGL.so;-lXt;-lSM;-lICE;-lSM;-lICE;-lSM;-lICE;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;")
SET(vtkRenderingTCL_LIB_DEPENDS "vtkRendering;vtkGraphicsTCL;vtkImagingTCL;/home/hayes/dart-slicer3-nightly/Slicer3/../Slicer3-lib/tcl-build/lib/libtk8.4.so;/home/hayes/dart-slicer3-nightly/Slicer3/../Slicer3-lib/tcl-build/lib/libtcl8.4.so;m;")
SET(vtkVolumeRendering_LIB_DEPENDS "vtkRendering;vtkIO;")
SET(vtkVolumeRenderingTCL_LIB_DEPENDS "vtkVolumeRendering;vtkRenderingTCL;vtkIOTCL;")
SET(vtkHybrid_LIB_DEPENDS "vtkRendering;vtkIO;vtkexoIIc;")
SET(vtkHybridTCL_LIB_DEPENDS "vtkHybrid;vtkRenderingTCL;vtkIOTCL;")
SET(vtkWidgets_LIB_DEPENDS "vtkRendering;vtkHybrid;")
SET(vtkWidgetsTCL_LIB_DEPENDS "vtkWidgets;vtkRenderingTCL;vtkHybridTCL;")
SET(vtksys_LIB_DEPENDS "")
SET(vtkzlib_LIB_DEPENDS "")
SET(vtkjpeg_LIB_DEPENDS "")
SET(vtkpng_LIB_DEPENDS "vtkzlib;")
SET(vtktiff_LIB_DEPENDS "vtkzlib;vtkjpeg;")
SET(vtkexpat_LIB_DEPENDS "")
SET(vtkfreetype_LIB_DEPENDS "")
SET(vtkDICOMParser_LIB_DEPENDS "")
SET(vtkNetCDF_LIB_DEPENDS "")
SET(vtkexoIIc_LIB_DEPENDS "vtkNetCDF;")
SET(vtkftgl_LIB_DEPENDS "/usr/lib/libGL.so;vtkfreetype;")

==> Slicer3-3.0.2008-01-05-linux-x86.tar.gz: Slicer3-3.0.2008-01-05-linux-x86/lib/vtk-5.0/VTKLibraryDepends.cmake <==
SET(vtkCommon_LIB_DEPENDS "vtksys;-lpthread;dl;-lm;")
SET(vtkCommonTCL_LIB_DEPENDS "vtkCommon;/home/hayes/Slicer3-release-gbt/Slicer3/../Slicer3-lib/tcl-build/lib/libtcl8.4.so;m;")
SET(vtkFiltering_LIB_DEPENDS "vtkCommon;")
SET(vtkFilteringTCL_LIB_DEPENDS "vtkFiltering;vtkCommonTCL;")
SET(vtkImaging_LIB_DEPENDS "vtkFiltering;")
SET(vtkImagingTCL_LIB_DEPENDS "vtkImaging;vtkFilteringTCL;")
SET(vtkGraphics_LIB_DEPENDS "vtkFiltering;")
SET(vtkGraphicsTCL_LIB_DEPENDS "vtkGraphics;vtkFilteringTCL;")
SET(vtkGenericFiltering_LIB_DEPENDS "vtkFiltering;vtkGraphics;")
SET(vtkGenericFilteringTCL_LIB_DEPENDS "vtkGenericFiltering;vtkFilteringTCL;vtkGraphicsTCL;")
SET(vtkIO_LIB_DEPENDS "vtkFiltering;vtkDICOMParser;vtkpng;vtkzlib;vtkjpeg;vtktiff;vtkexpat;")
SET(vtkIOTCL_LIB_DEPENDS "vtkIO;vtkFilteringTCL;")
SET(vtkRendering_LIB_DEPENDS "vtkGraphics;vtkImaging;vtkIO;vtkftgl;vtkfreetype;/usr/lib/libGL.so;-lXt;-lSM;-lICE;-lSM;-lICE;-lSM;-lICE;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;")
SET(vtkRenderingTCL_LIB_DEPENDS "vtkRendering;vtkGraphicsTCL;vtkImagingTCL;/home/hayes/Slicer3-release-gbt/Slicer3/../Slicer3-lib/tcl-build/lib/libtk8.4.so;/home/hayes/Slicer3-release-gbt/Slicer3/../Slicer3-lib/tcl-build/lib/libtcl8.4.so;m;")
SET(vtkVolumeRendering_LIB_DEPENDS "vtkRendering;vtkIO;")
SET(vtkVolumeRenderingTCL_LIB_DEPENDS "vtkVolumeRendering;vtkRenderingTCL;vtkIOTCL;")
SET(vtkHybrid_LIB_DEPENDS "vtkRendering;vtkIO;vtkexoIIc;")
SET(vtkHybridTCL_LIB_DEPENDS "vtkHybrid;vtkRenderingTCL;vtkIOTCL;")
SET(vtkWidgets_LIB_DEPENDS "vtkRendering;vtkHybrid;")
SET(vtkWidgetsTCL_LIB_DEPENDS "vtkWidgets;vtkRenderingTCL;vtkHybridTCL;")
SET(vtksys_LIB_DEPENDS "")
SET(vtkzlib_LIB_DEPENDS "")
SET(vtkjpeg_LIB_DEPENDS "")
SET(vtkpng_LIB_DEPENDS "vtkzlib;")
SET(vtktiff_LIB_DEPENDS "vtkzlib;vtkjpeg;")
SET(vtkexpat_LIB_DEPENDS "")
SET(vtkfreetype_LIB_DEPENDS "")
SET(vtkDICOMParser_LIB_DEPENDS "")
SET(vtkNetCDF_LIB_DEPENDS "")
SET(vtkexoIIc_LIB_DEPENDS "vtkNetCDF;")
SET(vtkftgl_LIB_DEPENDS "/usr/lib/libGL.so;vtkfreetype;")
